@@ -10,7 +10,7 @@ use DBI;
 use Data::PowerSet;
 use IO::File;
 
-our $VERSION = '0.0212';
+our $VERSION = '0.03';
 
 
 
@@ -171,7 +171,7 @@ sub power {
 #                warn "\tP:$compare v $mask\n";
 
                 # Skip this collection if an overlap is found.
-                if (not $self->does_not_overlap($compare, $mask)) {
+                if (not $self->_does_not_overlap($compare, $mask)) {
 #                    warn "\t\tO:$compare v $mask\n";
                     last LOOP;
                 }
@@ -192,12 +192,15 @@ sub power {
 
 sub score {
     my $self = shift;
+    my ( $open_sparator, $close_separator, $line_terminator ) = @_;
+
+    $line_terminator = '' unless defined $line_terminator;
 
     # Visit each combination...
     my $i = 0;
     for my $c (@{ $self->{combos} }) {
         $i++;
-        my $together = $self->or_together(@$c);
+        my $together = $self->_or_together(@$c);
 
         # Breakdown knowns vs unknowns and knowncharacters vs unknowncharacters.
         my %count = (
@@ -209,8 +212,8 @@ sub score {
         my $val = '';
         for my $x ( reverse sort @$c ) {
             # Run-length encode an "un-digitized" string.
-            my $y = rle($x);
-            my ( $knowns, $unknowns, $knownc, $unknownc ) = grouping($y);
+            my $y = _rle($x);
+            my ( $knowns, $unknowns, $knownc, $unknownc ) = _grouping($y);
 #            $val .= "$x ($y)[$knowns/$unknowns | $knownc/$unknownc] ";
             # Accumulate the counters!
             $count{knowns}   += $knowns;
@@ -219,13 +222,13 @@ sub score {
             $count{unknownc} += $unknownc;
         }
 
-        my ( $s, $m ) = reconstruct( $self->{word}, @$c );
+        my ( $s, $m ) = _reconstruct( $self->{word}, $c, $open_sparator, $close_separator );
 #        $val .= "$count{knowns}:$count{unknowns} chunks / $count{knownc}:$count{unknownc} chars => "
 #          . join( ', ', @$s );
 #        warn "V:$val\n";
 
         my $key = "$count{knowns}:$count{unknowns} chunks / $count{knownc}:$count{unknownc} chars";
-        $val = join '', @$s;
+        $val = join ", $line_terminator", @$s;
 
         # TODO Re-model the knowns!!
         my $defn = '';
@@ -233,7 +236,7 @@ sub score {
         {
             for my $j ( keys %{ $self->{known} } )
             {
-                $defn .= $self->{known}{$j}{defn} . '. ' if $self->{known}{$j}{mask} eq $i;
+                $defn .= $self->{known}{$j}{defn} . ". $line_terminator" if $self->{known}{$j}{mask} eq $i;
             }
         }
 
@@ -243,8 +246,7 @@ sub score {
     return $self->{score};
 }
 
-
-sub grouping {
+sub _grouping {
     my $scored = shift;
     my @groups = $scored =~ /([ku]\d+)/g;
     my ( $knowns, $unknowns ) = ( 0, 0 );
@@ -262,8 +264,7 @@ sub grouping {
     return $knowns, $unknowns, $knownc, $unknownc;
 }
 
-
-sub rle {
+sub _rle {
     my $scored = shift;
     # Run-length encode an "un-digitized" string.
     $scored =~ s/1/k/g; # Undigitize
@@ -273,8 +274,7 @@ sub rle {
     return $scored;
 }
 
-
-sub does_not_overlap {
+sub _does_not_overlap {
     my $self = shift;
 
     # Get our masks to check.
@@ -293,8 +293,7 @@ sub does_not_overlap {
     return $xorclone->equal($orclone) ? $orclone->to_Bin : 0;
 }
 
-
-sub or_together {
+sub _or_together {
     my $self = shift;
 
     # Get our masks to score.
@@ -315,36 +314,38 @@ sub or_together {
     return $result->to_Bin;
 }
 
+sub _reconstruct {
+    my ( $word, $masks, $open_separator, $close_separator ) = @_;
 
-sub reconstruct {
-    my ( $word, @masks ) = @_;
+    $open_separator  = '<' unless defined $open_separator;
+    $close_separator = '>' unless defined $close_separator;
 
-    my $strings = [];
-    my $masks   = [];
+    my $strings  = [];
+    my $my_masks = [];
 
-    for my $mask (reverse sort @masks) {
+    for my $mask (reverse sort @$masks) {
         my $i = 0;
         my $last = 0;
         my $string  = '';
         for my $m ( split //, $mask ) {
             if ( $m ) {
-                $string .= '<' unless $last;
+                $string .= $open_separator unless $last;
                 $string .= substr( $word, $i, 1 );
                 $last = 1;
             }
             else {
-                $string .= '>' if $last;
-#                $string .= substr( $word, $i, 1 );
+                $string .= $close_separator if $last;
+                $string .= substr( $word, $i, 1 );
                 $last = 0;
             }
             $i++;
         }
-        $string .= '>' if $last;
+        $string .= $close_separator if $last;
         push @$strings, $string;
-        push @$masks, $mask;
+        push @$my_masks, $mask;
     }
 
-    return $strings, $masks;
+    return $strings, $my_masks;
 }
 
 1;
@@ -361,7 +362,7 @@ Lingua::Word::Parser - Parse a word into known and unknown parts
 
 =head1 VERSION
 
-version 0.0212
+version 0.03
 
 =head1 SYNOPSIS
 
@@ -377,9 +378,9 @@ version 0.0212
     dbuser => 'akbar',
     dbpass => '0p3n53454m3',
  );
- my ($known) = $p->knowns; #warn Dumper $known;
- my $combos  = $p->power;  #warn Dumper $combos;
- my $scored  = $p->score;  #warn Dumper $score;
+ my ($known) = $p->knowns;
+ my $combos  = $p->power;
+ my $scored  = $p->score;
  # The best guess is the last sorted score-set:
  warn Dumper $scored->{ [ sort keys %$score ]->[-1] };
 
@@ -434,28 +435,13 @@ Find the "non-overlapping powerset."
 
 =head2 score()
 
+  $score = $p->score( $open_sparator, $close_separator, $line_terminator );
+
 Score the known vs unknown word part combinations into ratios of characters and
 chunks or parts or "spans of adjacent characters."
 
-=head2 grouping()
-
-Make groups of "un-digitized" strings where B<k> = known and B<u> = unknown.
-
-=head2 rle()
-
-Compress B<k>/B<u> strings into contiguous chunks.
-
-=head2 does_not_overlap()
-
-Compute whether the given masks overlap.
-
-=head2 or_together()
-
-Combine a list of bitmasks.
-
-=head2 reconstruct()
-
-Reconstruct the word, with delimiters around known combinations.
+If not given, the B<$open_sparator>, B<$close_separator> and B<$line_terminator>
+are '<', '>' and '', by default, respectively.
 
 =head1 SEE ALSO
 
